View source: R/classesWithMethod.R
| classesWithMethod | R Documentation |
List all classes that have a given S3 method
classesWithMethod(fooGeneric)
fooGeneric |
a generic function, or a character string naming a generic function. |
A character vector with the names of classes for which
generic.function is implemented.
Ute Hahn, ute@imf.au.dk
classesWithMethod("plot")
classesWithMethod(summary)
classesWithMethod("strangeStuff")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.