View source: R/matchingnames.R
| matching | R Documentation |
Finds elements in a list whose names match some given arguments
matching(x, ..., .notmatching = FALSE)
x |
named list, input elements |
... |
named lists, functions or function names |
.notmatching |
if |
For functions or functions names contained in ..., the argument
list is matched. This works only for non primitive functions.
a simplist containing those elements of x whose names match the
arguments, see details.
Ute Hahn, ute@imf.au.dk
A <- list(col = "red", xlab = "x", u = 13, v = 91)
B <- list(u = 5, t = 2)
str(matching(A, B))
str(matching(A, "plot.default"))
str(matching(A, plot.default, B))
# using predefined lists for graphical parameters, and plot.default parameters
str(matching(A, .graphparams, .plotparams))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.