plutils-package: Plotting with Style

plutils-packageR Documentation

Plotting with Style

Description

Provides utilities for handling plot and graphic parameters, plotting lists of objects, colour tools. Plotting with style: plot parameters can be given as lists.

Details

Functions for plotting with style, and plotting lists

splot plot using a list of parameters (a "simplist")
lplot plot all objects in a list
simplist collect parameters in a list

Utility functions

alphacol control transparency / brightness of a colour
matching match a list of parameters by name,
useful for sorting out parameters that throw warnings
when used in plot methods.
firstclass<- add a class to an object and forward this class
to the first place in the object's class list

Author(s)

Ute Hahn, ute@math.au.dk


plutils documentation built on Feb. 19, 2026, 3:01 a.m.