plutils-predefined: Predefined lists

Predefined parameter lists and optionsR Documentation

Predefined lists

Description

Predefined lists of parameters, for convenience

Usage

.plotparams

.graphparams

.plotoptions

Format

named lists

An object of class list of length 16.

An object of class list of length 66.

named lists

Details

.plotparams parameters that are used by plot.default, and that may
cause warnings in low level plotting functions, but not in plot.default
.graphparams graphical parameters that can be set by par,
no risk when passed to low level plotting functions.
.plotoptions options for the behaviour of functions in the plottools package.

plutils documentation built on Feb. 19, 2026, 3:01 a.m.